@@ -7,10 +7,9 @@
 #include <vector>
 #include "acceleration/Acceleration.hpp"
 #include "acceleration/AitkenAcceleration.hpp"
-#include "acceleration/BroydenAcceleration.hpp"
 #include "acceleration/ConstantRelaxationAcceleration.hpp"
 #include "acceleration/IQNILSAcceleration.hpp"
-#include "acceleration/MVQNAcceleration.hpp"
+#include "acceleration/IQNIMVJAcceleration.hpp"
 #include "acceleration/impl/ConstantPreconditioner.hpp"
 #include "acceleration/impl/QRFactorization.hpp"
 #include "acceleration/impl/ResidualPreconditioner.hpp"
@@ -25,8 +24,7 @@
 #include "xml/XMLAttribute.hpp"
 #include "xml/XMLTag.hpp"
 
-namespace precice {
-namespace acceleration {
+namespace precice::acceleration {
 
 using namespace precice::acceleration::impl;
 
@@ -50,18 +48,20 @@ AccelerationConfiguration::AccelerationConfiguration(
       ATTR_SINGULARITYLIMIT("limit"),
       ATTR_TYPE("type"),
       ATTR_BUILDJACOBIAN("always-build-jacobian"),
+      ATTR_REDUCEDTIMEGRIDQN("reduced-time-grid"),
       ATTR_IMVJCHUNKSIZE("chunk-size"),
       ATTR_RSLS_REUSED_TIME_WINDOWS("reused-time-windows-at-restart"),
       ATTR_RSSVD_TRUNCATIONEPS("truncation-threshold"),
       ATTR_PRECOND_NONCONST_TIME_WINDOWS("freeze-after"),
+      ATTR_PRECOND_UPDATE_ON_THRESHOLD("update-on-threshold"),
       VALUE_CONSTANT("constant"),
       VALUE_AITKEN("aitken"),
       VALUE_IQNILS("IQN-ILS"),
-      VALUE_MVQN("IQN-IMVJ"),
-      VALUE_BROYDEN("broyden"),
+      VALUE_IQNIMVJ("IQN-IMVJ"),
       VALUE_QR1FILTER("QR1"),
       VALUE_QR1_ABSFILTER("QR1-absolute"),
       VALUE_QR2FILTER("QR2"),
+      VALUE_QR3FILTER("QR3"),
       VALUE_CONSTANT_PRECONDITIONER("constant"),
       VALUE_VALUE_PRECONDITIONER("value"),
       VALUE_RESIDUAL_PRECONDITIONER("residual"),
@@ -104,11 +104,16 @@ void AccelerationConfiguration::connectTags(xml::XMLTag &parent)
   {
     XMLTag tag(*this, VALUE_IQNILS, occ, TAG);
     tag.setDocumentation("Accelerates coupling data with the interface quasi-Newton inverse least-squares method.");
+
+    auto reducedTimeGridQN = makeXMLAttribute(ATTR_REDUCEDTIMEGRIDQN, true)
+                                 .setDocumentation("Whether only the last time step of each time window is used to construct the Jacobian.");
+    tag.addAttribute(reducedTimeGridQN);
+
     addTypeSpecificSubtags(tag);
     tags.push_back(tag);
   }
   {
-    XMLTag tag(*this, VALUE_MVQN, occ, TAG);
+    XMLTag tag(*this, VALUE_IQNIMVJ, occ, TAG);
     tag.setDocumentation("Accelerates coupling data with the interface quasi-Newton inverse multi-vector Jacobian method.");
 
     auto alwaybuildJacobian = makeXMLAttribute(ATTR_BUILDJACOBIAN, false)
@@ -117,12 +122,10 @@ void AccelerationConfiguration::connectTags(xml::XMLTag &parent)
                                                     " the Jacobian is only build in the last iteration and the updates are computed using (relatively) cheap MATVEC products.");
     tag.addAttribute(alwaybuildJacobian);
 
-    addTypeSpecificSubtags(tag);
-    tags.push_back(tag);
-  }
-  {
-    XMLTag tag(*this, VALUE_BROYDEN, occ, TAG);
-    tag.setDocumentation("Accelerates coupling data with the (single-vector) Broyden method.");
+    auto reducedTimeGridQN = makeXMLAttribute(ATTR_REDUCEDTIMEGRIDQN, true)
+                                 .setDocumentation("Whether only the last time step of each time window is used to construct the Jacobian.");
+    tag.addAttribute(reducedTimeGridQN);
+
     addTypeSpecificSubtags(tag);
     tags.push_back(tag);
   }
@@ -139,31 +142,33 @@ PtrAcceleration AccelerationConfiguration::getAcceleration()
 
 void AccelerationConfiguration::xmlTagCallback(
     const xml::ConfigurationContext &context,
-    xml::XMLTag &                    callingTag)
+    xml::XMLTag                     &callingTag)
 {
   PRECICE_TRACE(callingTag.getFullName());
 
   if (callingTag.getNamespace() == TAG) {
     _config.type = callingTag.getName();
 
-    if (_config.type == VALUE_MVQN)
+    if (_config.type == VALUE_IQNIMVJ)
       _config.alwaysBuildJacobian = callingTag.getBooleanAttributeValue(ATTR_BUILDJACOBIAN);
-  }
 
+    if (_config.type == VALUE_IQNIMVJ || _config.type == VALUE_IQNILS)
+      _config.reducedTimeGridQN = callingTag.getBooleanAttributeValue(ATTR_REDUCEDTIMEGRIDQN);
+  }
   if (callingTag.getName() == TAG_RELAX) {
     _config.relaxationFactor = callingTag.getDoubleAttributeValue(ATTR_VALUE);
   } else if (callingTag.getName() == TAG_DATA) {
     std::string dataName = callingTag.getStringAttributeValue(ATTR_NAME);
     std::string meshName = callingTag.getStringAttributeValue(ATTR_MESH);
     auto        success  = _uniqueDataAndMeshNames.emplace(dataName, meshName);
-    if (not success.second) {
-      PRECICE_ERROR("You have provided a subtag <data name=\"{}\" mesh=\"{}\"/> more than once in your <acceleration:.../>. "
-                    "Please remove the duplicated entry.",
-                    dataName, meshName);
-    }
+    PRECICE_CHECK(success.second,
+                  "You have provided a subtag <data name=\"{}\" mesh=\"{}\"/> more than once in your <acceleration:.../>. "
+                  "Please remove the duplicated entry.",
+                  dataName, meshName);
+
     _meshName      = callingTag.getStringAttributeValue(ATTR_MESH);
     double scaling = 1.0;
-    if (_config.type == VALUE_IQNILS || _config.type == VALUE_MVQN || _config.type == VALUE_BROYDEN) {
+    if (_config.type == VALUE_IQNILS || _config.type == VALUE_IQNIMVJ) {
       scaling = callingTag.getDoubleAttributeValue(ATTR_SCALING);
     }
 
@@ -179,52 +184,58 @@ void AccelerationConfiguration::xmlTagCallback(
 
     _neededMeshes.push_back(_meshName);
   } else if (callingTag.getName() == TAG_INIT_RELAX) {
-    _config.relaxationFactor = callingTag.getDoubleAttributeValue(ATTR_VALUE);
+    _userDefinitions.definedRelaxationFactor = true;
+    _config.relaxationFactor                 = callingTag.getDoubleAttributeValue(ATTR_VALUE);
     if (callingTag.hasAttribute(ATTR_ENFORCE)) {
       _config.forceInitialRelaxation = callingTag.getBooleanAttributeValue(ATTR_ENFORCE);
     } else {
       _config.forceInitialRelaxation = false;
     }
   } else if (callingTag.getName() == TAG_MAX_USED_ITERATIONS) {
-    _config.maxIterationsUsed = callingTag.getIntAttributeValue(ATTR_VALUE);
+    _userDefinitions.definedMaxIterationsUsed = true;
+    _config.maxIterationsUsed                 = callingTag.getIntAttributeValue(ATTR_VALUE);
   } else if (callingTag.getName() == TAG_TIME_WINDOWS_REUSED) {
-    _config.timeWindowsReused = callingTag.getIntAttributeValue(ATTR_VALUE);
+    _userDefinitions.definedTimeWindowsReused = true;
+    _config.timeWindowsReused                 = callingTag.getIntAttributeValue(ATTR_VALUE);
   } else if (callingTag.getName() == TAG_FILTER) {
-    const auto &f = callingTag.getStringAttributeValue(ATTR_TYPE);
+    _userDefinitions.definedFilter = true;
+    const auto &f                  = callingTag.getStringAttributeValue(ATTR_TYPE);
     if (f == VALUE_QR1FILTER) {
       _config.filter = Acceleration::QR1FILTER;
     } else if (f == VALUE_QR1_ABSFILTER) {
       _config.filter = Acceleration::QR1FILTER_ABS;
     } else if (f == VALUE_QR2FILTER) {
       _config.filter = Acceleration::QR2FILTER;
+    } else if (f == VALUE_QR3FILTER) {
+      _config.filter = Acceleration::QR3FILTER;
     } else {
       PRECICE_ASSERT(false);
     }
     _config.singularityLimit = callingTag.getDoubleAttributeValue(ATTR_SINGULARITYLIMIT);
   } else if (callingTag.getName() == TAG_PRECONDITIONER) {
-    _config.preconditionerType         = callingTag.getStringAttributeValue(ATTR_TYPE);
-    _config.precond_nbNonConstTWindows = callingTag.getIntAttributeValue(ATTR_PRECOND_NONCONST_TIME_WINDOWS);
+    _userDefinitions.definedPreconditionerType = true;
+    _config.preconditionerType                 = callingTag.getStringAttributeValue(ATTR_TYPE);
+    _config.preconditionerUpdateOnThreshold    = callingTag.getBooleanAttributeValue(ATTR_PRECOND_UPDATE_ON_THRESHOLD);
+    _config.preconditionerNbNonConstTWindows   = callingTag.getIntAttributeValue(ATTR_PRECOND_NONCONST_TIME_WINDOWS);
   } else if (callingTag.getName() == TAG_IMVJRESTART) {
-
-    if (_config.alwaysBuildJacobian)
-      PRECICE_ERROR("IMVJ cannot be in restart mode while parameter always-build-jacobian is set to true. "
-                    "Please remove 'always-build-jacobian' from the configuration file or do not run in restart mode.");
-
+    _userDefinitions.defineRestartType = true;
 #ifndef PRECICE_NO_MPI
     _config.imvjChunkSize = callingTag.getIntAttributeValue(ATTR_IMVJCHUNKSIZE);
     const auto &f         = callingTag.getStringAttributeValue(ATTR_TYPE);
+    PRECICE_CHECK((f == VALUE_NO_RESTART) || (!_config.alwaysBuildJacobian), "IMVJ cannot be in restart mode while parameter always-build-jacobian is set to true. "
+                                                                             "Please remove 'always-build-jacobian' from the configuration file or do not run in restart mode.");
     if (f == VALUE_NO_RESTART) {
-      _config.imvjRestartType = MVQNAcceleration::NO_RESTART;
+      _config.imvjRestartType = IQNIMVJAcceleration::NO_RESTART;
     } else if (f == VALUE_ZERO_RESTART) {
-      _config.imvjRestartType = MVQNAcceleration::RS_ZERO;
+      _config.imvjRestartType = IQNIMVJAcceleration::RS_ZERO;
     } else if (f == VALUE_LS_RESTART) {
       _config.imvjRSLS_reusedTimeWindows = callingTag.getIntAttributeValue(ATTR_RSLS_REUSED_TIME_WINDOWS);
-      _config.imvjRestartType            = MVQNAcceleration::RS_LS;
+      _config.imvjRestartType            = IQNIMVJAcceleration::RS_LS;
     } else if (f == VALUE_SVD_RESTART) {
       _config.imvjRSSVD_truncationEps = callingTag.getDoubleAttributeValue(ATTR_RSSVD_TRUNCATIONEPS);
-      _config.imvjRestartType         = MVQNAcceleration::RS_SVD;
+      _config.imvjRestartType         = IQNIMVJAcceleration::RS_SVD;
     } else if (f == VALUE_SLIDE_RESTART) {
-      _config.imvjRestartType = MVQNAcceleration::RS_SLIDE;
+      _config.imvjRestartType = IQNIMVJAcceleration::RS_SLIDE;
     } else {
       _config.imvjChunkSize = 0;
       PRECICE_ASSERT(false);
@@ -237,51 +248,44 @@ void AccelerationConfiguration::xmlTagCallback(
 
 void AccelerationConfiguration::xmlEndTagCallback(
     const xml::ConfigurationContext &context,
-    xml::XMLTag &                    callingTag)
+    xml::XMLTag                     &callingTag)
 {
   PRECICE_TRACE(callingTag.getName());
   if (callingTag.getNamespace() == TAG) {
 
-    //create preconditioner
-    if (callingTag.getName() == VALUE_IQNILS || callingTag.getName() == VALUE_MVQN) {
-
-      // if imvj restart-mode is of type RS-SVD, max number of non-const preconditioned time windows is limited by the chunksize
-      if (callingTag.getName() == VALUE_MVQN && _config.imvjRestartType > 0)
-        if (_config.precond_nbNonConstTWindows > _config.imvjChunkSize)
-          _config.precond_nbNonConstTWindows = _config.imvjChunkSize;
-
+    // create preconditioner
+    if (callingTag.getName() == VALUE_IQNILS || callingTag.getName() == VALUE_AITKEN) {
       if (_config.preconditionerType == VALUE_CONSTANT_PRECONDITIONER) {
-        std::vector<double> factors;
-        for (int id : _config.dataIDs) {
-          factors.push_back(_config.scalings[id]);
-        }
-        _preconditioner = PtrPreconditioner(new ConstantPreconditioner(factors));
+        _preconditioner = PtrPreconditioner(new ConstantPreconditioner(_config.scalingFactorsInOrder()));
       } else if (_config.preconditionerType == VALUE_VALUE_PRECONDITIONER) {
-        _preconditioner = PtrPreconditioner(new ValuePreconditioner(_config.precond_nbNonConstTWindows));
+        _preconditioner = PtrPreconditioner(new ValuePreconditioner(_config.preconditionerNbNonConstTWindows));
       } else if (_config.preconditionerType == VALUE_RESIDUAL_PRECONDITIONER) {
-        _preconditioner = PtrPreconditioner(new ResidualPreconditioner(_config.precond_nbNonConstTWindows));
+        _preconditioner = PtrPreconditioner(new ResidualPreconditioner(_config.preconditionerNbNonConstTWindows));
       } else if (_config.preconditionerType == VALUE_RESIDUAL_SUM_PRECONDITIONER) {
-        _preconditioner = PtrPreconditioner(new ResidualSumPreconditioner(_config.precond_nbNonConstTWindows));
+        _preconditioner = PtrPreconditioner(new ResidualSumPreconditioner(_config.preconditionerNbNonConstTWindows, _config.preconditionerUpdateOnThreshold));
       } else {
         // no preconditioner defined
-        std::vector<double> factors;
-        for (int id = 0; id < static_cast<int>(_config.dataIDs.size()); ++id) {
-          factors.push_back(1.0);
-        }
-        _preconditioner = PtrPreconditioner(new ConstantPreconditioner(factors));
+        _preconditioner = PtrPreconditioner(new ResidualSumPreconditioner(_defaultValuesIQNILS.preconditionerNbNonConstTWindows, _defaultValuesIQNILS.preconditionerUpdateOnThreshold));
       }
     }
 
+    PRECICE_CHECK(!_acceleration, "You are trying to define multiple acceleration schemes, which is not allowed. Please remove one of them.");
     if (callingTag.getName() == VALUE_CONSTANT) {
       _acceleration = PtrAcceleration(
           new ConstantRelaxationAcceleration(
               _config.relaxationFactor, _config.dataIDs));
     } else if (callingTag.getName() == VALUE_AITKEN) {
-      _acceleration = PtrAcceleration(
+      _config.relaxationFactor = (_userDefinitions.definedRelaxationFactor) ? _config.relaxationFactor : _defaultAitkenRelaxationFactor;
+      _acceleration            = PtrAcceleration(
           new AitkenAcceleration(
-              _config.relaxationFactor, _config.dataIDs));
+              _config.relaxationFactor, _config.dataIDs, _preconditioner));
     } else if (callingTag.getName() == VALUE_IQNILS) {
-      _acceleration = PtrAcceleration(
+      _config.relaxationFactor  = (_userDefinitions.definedRelaxationFactor) ? _config.relaxationFactor : _defaultValuesIQNILS.relaxationFactor;
+      _config.maxIterationsUsed = (_userDefinitions.definedMaxIterationsUsed) ? _config.maxIterationsUsed : _defaultValuesIQNILS.maxIterationsUsed;
+      _config.timeWindowsReused = (_userDefinitions.definedTimeWindowsReused) ? _config.timeWindowsReused : _defaultValuesIQNILS.timeWindowsReused;
+      _config.filter            = (_userDefinitions.definedFilter) ? _config.filter : _defaultValuesIQNILS.filter;
+      _config.singularityLimit  = (_userDefinitions.definedFilter) ? _config.singularityLimit : _defaultValuesIQNILS.singularityLimit;
+      _acceleration             = PtrAcceleration(
           new IQNILSAcceleration(
               _config.relaxationFactor,
               _config.forceInitialRelaxation,
@@ -289,11 +293,41 @@ void AccelerationConfiguration::xmlEndTagCallback(
               _config.timeWindowsReused,
               _config.filter, _config.singularityLimit,
               _config.dataIDs,
-              _preconditioner));
-    } else if (callingTag.getName() == VALUE_MVQN) {
+              _preconditioner,
+              _config.reducedTimeGridQN));
+    } else if (callingTag.getName() == VALUE_IQNIMVJ) {
 #ifndef PRECICE_NO_MPI
+      _config.relaxationFactor  = (_userDefinitions.definedRelaxationFactor) ? _config.relaxationFactor : _defaultValuesIQNIMVJ.relaxationFactor;
+      _config.maxIterationsUsed = (_userDefinitions.definedMaxIterationsUsed) ? _config.maxIterationsUsed : _defaultValuesIQNIMVJ.maxIterationsUsed;
+      _config.timeWindowsReused = (_userDefinitions.definedTimeWindowsReused) ? _config.timeWindowsReused : _defaultValuesIQNIMVJ.timeWindowsReused;
+      _config.filter            = (_userDefinitions.definedFilter) ? _config.filter : _defaultValuesIQNILS.filter;
+      _config.singularityLimit  = (_userDefinitions.definedFilter) ? _config.singularityLimit : _defaultValuesIQNILS.singularityLimit;
+      if (!_config.alwaysBuildJacobian) {
+        _config.imvjRestartType = (_userDefinitions.defineRestartType) ? _config.imvjRestartType : _defaultValuesIQNIMVJ.imvjRestartType;
+        _config.imvjChunkSize   = (_userDefinitions.defineRestartType) ? _config.imvjChunkSize : _defaultValuesIQNIMVJ.imvjChunkSize;
+      }
+
+      // create preconditioner
+      // if imvj restart-mode is of type RS-SVD, max number of non-const preconditioned time windows is limited by the chunksize
+      // it is separated from the other acceleration methods, since SVD-restart might be chosen as default here
+      if (_config.imvjRestartType == IQNIMVJAcceleration::RS_SVD)
+        if (_config.preconditionerNbNonConstTWindows > _config.imvjChunkSize)
+          _config.preconditionerNbNonConstTWindows = _config.imvjChunkSize;
+      if (_config.preconditionerType == VALUE_CONSTANT_PRECONDITIONER) {
+        _preconditioner = PtrPreconditioner(new ConstantPreconditioner(_config.scalingFactorsInOrder()));
+      } else if (_config.preconditionerType == VALUE_VALUE_PRECONDITIONER) {
+        _preconditioner = PtrPreconditioner(new ValuePreconditioner(_config.preconditionerNbNonConstTWindows));
+      } else if (_config.preconditionerType == VALUE_RESIDUAL_PRECONDITIONER) {
+        _preconditioner = PtrPreconditioner(new ResidualPreconditioner(_config.preconditionerNbNonConstTWindows));
+      } else if (_config.preconditionerType == VALUE_RESIDUAL_SUM_PRECONDITIONER) {
+        _preconditioner = PtrPreconditioner(new ResidualSumPreconditioner(_config.preconditionerNbNonConstTWindows, _config.preconditionerUpdateOnThreshold));
+      } else {
+        // no preconditioner defined
+        _preconditioner = PtrPreconditioner(new ResidualSumPreconditioner(_defaultValuesIQNILS.preconditionerNbNonConstTWindows, _defaultValuesIQNIMVJ.preconditionerUpdateOnThreshold));
+      }
+
       _acceleration = PtrAcceleration(
-          new MVQNAcceleration(
+          new IQNIMVJAcceleration(
               _config.relaxationFactor,
               _config.forceInitialRelaxation,
               _config.maxIterationsUsed,
@@ -305,20 +339,11 @@ void AccelerationConfiguration::xmlEndTagCallback(
               _config.imvjRestartType,
               _config.imvjChunkSize,
               _config.imvjRSLS_reusedTimeWindows,
-              _config.imvjRSSVD_truncationEps));
+              _config.imvjRSSVD_truncationEps,
+              _config.reducedTimeGridQN));
 #else
       PRECICE_ERROR("Acceleration IQN-IMVJ only works if preCICE is compiled with MPI");
 #endif
-    } else if (callingTag.getName() == VALUE_BROYDEN) {
-      _acceleration = PtrAcceleration(
-          new BroydenAcceleration(
-              _config.relaxationFactor,
-              _config.forceInitialRelaxation,
-              _config.maxIterationsUsed,
-              _config.timeWindowsReused,
-              _config.filter, _config.singularityLimit,
-              _config.dataIDs,
-              _preconditioner));
     } else {
       PRECICE_ASSERT(false);
     }
@@ -327,8 +352,9 @@ void AccelerationConfiguration::xmlEndTagCallback(
 
 void AccelerationConfiguration::clear()
 {
-  _config       = ConfigurationData();
-  _acceleration = PtrAcceleration();
+  _config          = ConfigurationData();
+  _userDefinitions = UserDefinitions();
+  _acceleration    = PtrAcceleration();
   _neededMeshes.clear();
 }
 
@@ -345,7 +371,8 @@ void AccelerationConfiguration::addCommonIQNSubtags(xml::XMLTag &tag)
   auto attrScaling = makeXMLAttribute(ATTR_SCALING, 1.0)
                          .setDocumentation(
                              "To improve the performance of a parallel or a multi coupling schemes, "
-                             "data values can be manually scaled. We recommend, however, to use an automatic scaling via a preconditioner.");
+                             "each data set can be manually scaled using this scaling factor with preconditioner type = \"constant\". For all other preconditioner types, the factor is ignored. "
+                             "We recommend, however, to use an automatic scaling via a preconditioner.");
   tagData.addAttribute(attrScaling);
   tagData.addAttribute(attrName);
   tagData.addAttribute(attrMesh);
@@ -359,14 +386,16 @@ void AccelerationConfiguration::addCommonIQNSubtags(xml::XMLTag &tag)
                              " - `QR2-filter`: en-block QR-dec with test \\\\(\\lVert v_\\text{orth} \\rVert_2 < \\epsilon * \\lVert v \\rVert_2\\\\)\n\n"
                              "Please note that a QR1 is based on Given's rotations whereas QR2 uses "
                              "modified Gram-Schmidt. This can give different results even when no columns "
-                             "are filtered out.");
+                             "are filtered out.\n"
+                             "When this tag is not provided, the QR2-filter with the limit value 1e-2 is used.");
   XMLAttribute<double> attrSingularityLimit(ATTR_SINGULARITYLIMIT, 1e-16);
   attrSingularityLimit.setDocumentation("Limit eps of the filter.");
   tagFilter.addAttribute(attrSingularityLimit);
   auto attrFilterName = XMLAttribute<std::string>(ATTR_TYPE)
                             .setOptions({VALUE_QR1FILTER,
                                          VALUE_QR1_ABSFILTER,
-                                         VALUE_QR2FILTER})
+                                         VALUE_QR2FILTER,
+                                         VALUE_QR3FILTER})
                             .setDocumentation("Type of the filter.");
   tagFilter.addAttribute(attrFilterName);
   tag.addSubtag(tagFilter);
@@ -383,8 +412,8 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
     tagRelax.addAttribute(attrValue);
     tag.addSubtag(tagRelax);
   } else if (tag.getName() == VALUE_AITKEN) {
-    XMLTag tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_ONCE);
-    tagInitRelax.setDocumentation("Initial relaxation factor.");
+    XMLTag tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagInitRelax.setDocumentation("Initial relaxation factor. If this tag is not provided, an initial relaxation of 0.5 is used.");
     XMLAttribute<double> attrValue(ATTR_VALUE);
     attrValue.setDocumentation("Initial relaxation factor.");
     tagInitRelax.addAttribute(attrValue);
@@ -396,38 +425,18 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
     attrName.setDocumentation("The name of the data.");
     XMLAttribute<std::string> attrMesh(ATTR_MESH);
     attrMesh.setDocumentation("The name of the mesh which holds the data.");
+    auto attrScaling = makeXMLAttribute(ATTR_SCALING, 1.0)
+                           .setDocumentation(
+                               "To improve the performance of a parallel or a multi coupling schemes, "
+                               "each data set can be manually scaled using this scaling factor with preconditioner type = \"constant\". For all other preconditioner types, the factor is ignored. "
+                               "We recommend, however, to use an automatic scaling via a preconditioner.");
+    tagData.addAttribute(attrScaling);
     tagData.addAttribute(attrName);
     tagData.addAttribute(attrMesh);
     tag.addSubtag(tagData);
-  } else if (tag.getName() == VALUE_IQNILS) {
-    XMLTag tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_ONCE);
-    tagInitRelax.setDocumentation("Initial relaxation factor.");
-    XMLAttribute<double> attrDoubleValue(ATTR_VALUE);
-    attrDoubleValue.setDocumentation("Initial relaxation factor.");
-    tagInitRelax.addAttribute(attrDoubleValue);
-    XMLAttribute<bool> attrEnforce(ATTR_ENFORCE, false);
-    attrEnforce.setDocumentation("Enforce initial relaxation in every time window.");
-    tagInitRelax.addAttribute(attrEnforce);
-    tag.addSubtag(tagInitRelax);
-
-    XMLTag tagMaxUsedIter(*this, TAG_MAX_USED_ITERATIONS, XMLTag::OCCUR_ONCE);
-    tagMaxUsedIter.setDocumentation("Maximum number of columns used in low-rank approximation of Jacobian.");
-    XMLAttribute<int> attrIntValue(ATTR_VALUE);
-    attrIntValue.setDocumentation("The number of columns.");
-    tagMaxUsedIter.addAttribute(attrIntValue);
-    tag.addSubtag(tagMaxUsedIter);
-
-    XMLTag tagTimeWindowsReused(*this, TAG_TIME_WINDOWS_REUSED, XMLTag::OCCUR_ONCE);
-    tagTimeWindowsReused.setDocumentation("Number of past time windows from which columns are used to approximate Jacobian.");
-    XMLAttribute<int> attrNumTimeWindowsReused(ATTR_VALUE);
-    attrNumTimeWindowsReused.setDocumentation("The number of time windows.");
-    tagTimeWindowsReused.addAttribute(attrNumTimeWindowsReused);
-    tag.addSubtag(tagTimeWindowsReused);
-
-    addCommonIQNSubtags(tag);
 
     XMLTag tagPreconditioner(*this, TAG_PRECONDITIONER, XMLTag::OCCUR_NOT_OR_ONCE);
-    tagPreconditioner.setDocumentation("To improve the performance of a parallel or a multi coupling schemes a preconditioner"
+    tagPreconditioner.setDocumentation("To improve the numerical stability of multiple data vectors a preconditioner"
                                        " can be applied. A constant preconditioner scales every acceleration data by a constant value, which you can define as"
                                        " an attribute of data. "
                                        " A value preconditioner scales every acceleration data by the norm of the data in the previous time window."
@@ -446,10 +455,64 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
                                     "are frozen and the preconditioner acts like a constant preconditioner.");
     tagPreconditioner.addAttribute(nonconstTWindows);
     tag.addSubtag(tagPreconditioner);
+  } else if (tag.getName() == VALUE_IQNILS) {
 
-  } else if (tag.getName() == VALUE_MVQN) {
-    XMLTag tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_ONCE);
-    tagInitRelax.setDocumentation("Initial relaxation factor.");
+    XMLTag tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagInitRelax.setDocumentation("Initial relaxation factor. If this tag is not provided, an initial relaxation of 0.1 is used.");
+    XMLAttribute<double> attrDoubleValue(ATTR_VALUE);
+    attrDoubleValue.setDocumentation("Initial relaxation factor.");
+    tagInitRelax.addAttribute(attrDoubleValue);
+    XMLAttribute<bool> attrEnforce(ATTR_ENFORCE, false);
+    attrEnforce.setDocumentation("Enforce initial relaxation in every time window.");
+    tagInitRelax.addAttribute(attrEnforce);
+    tag.addSubtag(tagInitRelax);
+
+    XMLTag tagMaxUsedIter(*this, TAG_MAX_USED_ITERATIONS, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagMaxUsedIter.setDocumentation("Maximum number of columns used in low-rank approximation of Jacobian. If this tag is not provided, the attribute value of 100 is used.");
+    XMLAttribute<int> attrIntValue(ATTR_VALUE);
+    attrIntValue.setDocumentation("The number of columns.");
+    tagMaxUsedIter.addAttribute(attrIntValue);
+    tag.addSubtag(tagMaxUsedIter);
+
+    XMLTag tagTimeWindowsReused(*this, TAG_TIME_WINDOWS_REUSED, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagTimeWindowsReused.setDocumentation("Number of past time windows from which columns are used to approximate Jacobian. If this tag is not provided, the default attribute value of 10 is used.");
+    XMLAttribute<int> attrNumTimeWindowsReused(ATTR_VALUE);
+    attrNumTimeWindowsReused.setDocumentation("The number of time windows.");
+    tagTimeWindowsReused.addAttribute(attrNumTimeWindowsReused);
+    tag.addSubtag(tagTimeWindowsReused);
+
+    addCommonIQNSubtags(tag);
+
+    XMLTag tagPreconditioner(*this, TAG_PRECONDITIONER, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagPreconditioner.setDocumentation("To improve the performance of a parallel or a multi coupling schemes a preconditioner"
+                                       " can be applied. "
+                                       "- A constant preconditioner scales every acceleration data by a constant value, which you can define as an attribute of data. \n "
+                                       "- A value preconditioner scales every acceleration data by the norm of the data in the previous time window.\n"
+                                       "- A residual preconditioner scales every acceleration data by the current residual.\n"
+                                       "- A residual-sum preconditioner scales every acceleration data by the sum of the residuals from the current time window.\n"
+                                       " If this tag is not provided, the residual-sum preconditioner is employed.");
+    auto attrPreconditionerType = XMLAttribute<std::string>(ATTR_TYPE)
+                                      .setOptions({VALUE_CONSTANT_PRECONDITIONER,
+                                                   VALUE_VALUE_PRECONDITIONER,
+                                                   VALUE_RESIDUAL_PRECONDITIONER,
+                                                   VALUE_RESIDUAL_SUM_PRECONDITIONER})
+                                      .setDocumentation("The type of the preconditioner.");
+    tagPreconditioner.addAttribute(attrPreconditionerType);
+    auto attrpreconditionerUpdateOnThreshold = XMLAttribute<bool>(ATTR_PRECOND_UPDATE_ON_THRESHOLD, true)
+                                                   .setDocumentation("To update the preconditioner weights after the first time window:"
+                                                                     "- `true`: The preconditioner weights are only updated if the weights will change by more than one order of magnitude.\n"
+                                                                     "- `false`: The preconditioner weights are updated after every iteration.");
+    tagPreconditioner.addAttribute(attrpreconditionerUpdateOnThreshold);
+    auto nonconstTWindows = makeXMLAttribute(ATTR_PRECOND_NONCONST_TIME_WINDOWS, -1)
+                                .setDocumentation(
+                                    "After the given number of time windows, the preconditioner weights "
+                                    "are frozen and the preconditioner acts like a constant preconditioner.");
+    tagPreconditioner.addAttribute(nonconstTWindows);
+    tag.addSubtag(tagPreconditioner);
+
+  } else if (tag.getName() == VALUE_IQNIMVJ) {
+    XMLTag tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagInitRelax.setDocumentation("Initial relaxation factor. If this tag is not provided, an initial relaxation of 0.1 is used.");
     tagInitRelax.addAttribute(
         XMLAttribute<double>(ATTR_VALUE).setDocumentation("Initial relaxation factor."));
     tagInitRelax.addAttribute(
@@ -468,10 +531,11 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
     tagIMVJRESTART.addAttribute(attrRestartName);
     tagIMVJRESTART.setDocumentation("Type of IMVJ restart mode that is used:\n"
                                     "- `no-restart`: IMVJ runs in normal mode with explicit representation of Jacobian\n"
-                                    "- `RS-ZERO`:    IMVJ runs in restart mode. After M time windows all Jacobain information is dropped, restart with no information\n"
+                                    "- `RS-0`:    IMVJ runs in restart mode. After M time windows all Jacobain information is dropped, restart with no information\n"
                                     "- `RS-LS`:      IMVJ runs in restart mode. After M time windows a IQN-LS like approximation for the initial guess of the Jacobian is computed.\n"
                                     "- `RS-SVD`:     IMVJ runs in restart mode. After M time windows a truncated SVD of the Jacobian is updated.\n"
-                                    "- `RS-SLIDE`:   IMVJ runs in sliding window restart mode.\n");
+                                    "- `RS-SLIDE`:   IMVJ runs in sliding window restart mode.\n"
+                                    "If this tag is not provided, IMVJ runs in restart mode with SVD-method.");
     auto attrChunkSize = makeXMLAttribute(ATTR_IMVJCHUNKSIZE, 8)
                              .setDocumentation("Specifies the number of time windows M after which the IMVJ restarts, if run in restart-mode. Default value is M=8.");
     auto attrReusedTimeWindowsAtRestart = makeXMLAttribute(ATTR_RSLS_REUSED_TIME_WINDOWS, 8)
@@ -483,15 +547,15 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
     tagIMVJRESTART.addAttribute(attrRSSVD_truncationEps);
     tag.addSubtag(tagIMVJRESTART);
 
-    XMLTag tagMaxUsedIter(*this, TAG_MAX_USED_ITERATIONS, XMLTag::OCCUR_ONCE);
-    tagMaxUsedIter.setDocumentation("Maximum number of columns used in low-rank approximation of Jacobian.");
+    XMLTag tagMaxUsedIter(*this, TAG_MAX_USED_ITERATIONS, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagMaxUsedIter.setDocumentation("Maximum number of columns used in low-rank approximation of Jacobian. If this tag is not provided, the default attribute value of 20 is used.");
     XMLAttribute<int> attrIntValue(ATTR_VALUE);
     attrIntValue.setDocumentation("The number of columns.");
     tagMaxUsedIter.addAttribute(attrIntValue);
     tag.addSubtag(tagMaxUsedIter);
 
-    XMLTag tagTimeWindowsReused(*this, TAG_TIME_WINDOWS_REUSED, XMLTag::OCCUR_ONCE);
-    tagTimeWindowsReused.setDocumentation("Number of past time windows from which columns are used to approximate Jacobian.");
+    XMLTag tagTimeWindowsReused(*this, TAG_TIME_WINDOWS_REUSED, XMLTag::OCCUR_NOT_OR_ONCE);
+    tagTimeWindowsReused.setDocumentation("Number of past time windows from which columns are used to approximate Jacobian. If this tag is not provided, the attribute value of 0 is used.");
     tagTimeWindowsReused.addAttribute(attrIntValue);
     tag.addSubtag(tagTimeWindowsReused);
 
@@ -499,12 +563,12 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
 
     XMLTag tagPreconditioner(*this, TAG_PRECONDITIONER, XMLTag::OCCUR_NOT_OR_ONCE);
     tagPreconditioner.setDocumentation(
-        "To improve the performance of a parallel or a multi coupling schemes a preconditioner"
-        " can be applied. A constant preconditioner scales every acceleration data by a constant value, which you can define as"
-        " an attribute of data.\n"
+        "To improve the performance of a parallel or a multi coupling schemes a preconditioner can be applied."
+        "- A constant preconditioner scales every acceleration data by a constant value, which you can define as an attribute of data.\n"
         "- A value preconditioner scales every acceleration data by the norm of the data in the previous time window.\n"
         "- A residual preconditioner scales every acceleration data by the current residual.\n"
-        "- A residual-sum preconditioner scales every acceleration data by the sum of the residuals from the current time window.\n");
+        "- A residual-sum preconditioner scales every acceleration data by the sum of the residuals from the current time window.\n"
+        " If this tag is not provided, the residual-sum preconditioner is employed.");
     auto attrPreconditionerType = XMLAttribute<std::string>(ATTR_TYPE)
                                       .setOptions({VALUE_CONSTANT_PRECONDITIONER,
                                                    VALUE_VALUE_PRECONDITIONER,
@@ -512,42 +576,28 @@ void AccelerationConfiguration::addTypeSpecificSubtags(
                                                    VALUE_RESIDUAL_SUM_PRECONDITIONER})
                                       .setDocumentation("Type of the preconditioner.");
     tagPreconditioner.addAttribute(attrPreconditionerType);
+    auto attrpreconditionerUpdateOnThreshold = XMLAttribute<bool>(ATTR_PRECOND_UPDATE_ON_THRESHOLD, true)
+                                                   .setDocumentation("To update the preconditioner weights after the first time window:"
+                                                                     "- `true`:  The preconditioner weights are only updated if the weights will change by more than one order of magnitude.\n"
+                                                                     "- `false`: The preconditioner weights are updated after every iteration.");
+    tagPreconditioner.addAttribute(attrpreconditionerUpdateOnThreshold);
     auto nonconstTWindows = makeXMLAttribute(ATTR_PRECOND_NONCONST_TIME_WINDOWS, -1)
                                 .setDocumentation("After the given number of time windows, the preconditioner weights are frozen and the preconditioner acts like a constant preconditioner.");
     tagPreconditioner.addAttribute(nonconstTWindows);
     tag.addSubtag(tagPreconditioner);
 
-  } else if (tag.getName() == VALUE_BROYDEN) {
-    XMLTag               tagInitRelax(*this, TAG_INIT_RELAX, XMLTag::OCCUR_ONCE);
-    XMLAttribute<double> attrDoubleValue(ATTR_VALUE);
-    tagInitRelax.addAttribute(attrDoubleValue);
-    XMLAttribute<bool> attrEnforce(ATTR_ENFORCE, false);
-    tagInitRelax.addAttribute(attrEnforce);
-    tag.addSubtag(tagInitRelax);
-
-    XMLTag            tagMaxUsedIter(*this, TAG_MAX_USED_ITERATIONS, XMLTag::OCCUR_ONCE);
-    XMLAttribute<int> attrIntValue(ATTR_VALUE);
-    tagMaxUsedIter.addAttribute(attrIntValue);
-    tag.addSubtag(tagMaxUsedIter);
-
-    XMLTag tagTimeWindowsReused(*this, TAG_TIME_WINDOWS_REUSED, XMLTag::OCCUR_ONCE);
-    tagTimeWindowsReused.addAttribute(attrIntValue);
-    tag.addSubtag(tagTimeWindowsReused);
-
-    XMLTag                    tagData(*this, TAG_DATA, XMLTag::OCCUR_ONCE_OR_MORE);
-    XMLAttribute<std::string> attrName(ATTR_NAME);
-    XMLAttribute<std::string> attrMesh(ATTR_MESH);
-    auto                      attrScaling = makeXMLAttribute(ATTR_SCALING, 1.0)
-                           .setDocumentation(
-                               "To improve the performance of a parallel or a multi coupling schemes, "
-                               "data values can be manually scaled. We recommend, however, to use an automatic scaling via a preconditioner.");
-    tagData.addAttribute(attrScaling);
-    tagData.addAttribute(attrName);
-    tagData.addAttribute(attrMesh);
-    tag.addSubtag(tagData);
   } else {
     PRECICE_ERROR("Acceleration of type \"{}\" is unknown. Please choose a valid acceleration scheme or check the spelling in the configuration file.", tag.getName());
   }
 }
-} // namespace acceleration
-} // namespace precice
+
+std::vector<double> AccelerationConfiguration::ConfigurationData::scalingFactorsInOrder() const
+{
+  std::vector<double> factors;
+  for (int id : dataIDs) {
+    factors.push_back(scalings.at(id));
+  }
+  return factors;
+}
+
+} // namespace precice::acceleration
