@@ -1,12 +1,11 @@
 #include "acceleration/impl/ValuePreconditioner.hpp"
 #include <cstddef>
 #include <vector>
+#include "math/differences.hpp"
 #include "utils/IntraComm.hpp"
 #include "utils/assertion.hpp"
 
-namespace precice {
-namespace acceleration {
-namespace impl {
+namespace precice::acceleration::impl {
 
 ValuePreconditioner::ValuePreconditioner(
     int maxNonConstTimeWindows)
@@ -30,14 +29,21 @@ void ValuePreconditioner::_update_(bool                   timeWindowComplete,
       }
       norms[k] = utils::IntraComm::l2norm(part);
       offset += _subVectorSizes[k];
-      PRECICE_ASSERT(norms[k] > 0.0);
     }
 
     offset = 0;
     for (size_t k = 0; k < _subVectorSizes.size(); k++) {
-      for (size_t i = 0; i < _subVectorSizes[k]; i++) {
-        _weights[i + offset]    = 1.0 / norms[k];
-        _invWeights[i + offset] = norms[k];
+      if (norms[k] < math::NUMERICAL_ZERO_DIFFERENCE) {
+        PRECICE_WARN("A sub-vector in the residual preconditioner became numerically zero. "
+                     "If this occurred in the second iteration and the initial-relaxation factor is equal to 1.0, "
+                     "check if the coupling data values of one solver is zero in the first iteration. "
+                     "The preconditioner scaling factors were not applied for this iteration.");
+      } else {
+        for (size_t i = 0; i < _subVectorSizes[k]; i++) {
+          PRECICE_ASSERT(norms[k] > 0.0);
+          _weights[i + offset]    = 1.0 / norms[k];
+          _invWeights[i + offset] = norms[k];
+        }
       }
       offset += _subVectorSizes[k];
     }
@@ -47,6 +53,4 @@ void ValuePreconditioner::_update_(bool                   timeWindowComplete,
   }
 }
 
-} // namespace impl
-} // namespace acceleration
-} // namespace precice
+} // namespace precice::acceleration::impl
