@@ -6,34 +6,27 @@
 #include "logging/Logger.hpp"
 #include "mesh/SharedPointer.hpp"
 
-namespace precice {
-namespace action {
+namespace precice::action {
 
 /// Action that adds multiple source data into target data
 class SummationAction : public Action {
 public:
   /**
-	 * @brief Constructor
-	 * 
-	 * @param[in] Timing When to apply the action
-	 * @param[in] sourceDataIDs Data indexes which are to be added
-	 * @param[in] targetDataID Data in which the action will be applied
-	 * 
-	 */
+   * @brief Constructor
+   *
+   * @param[in] Timing When to apply the action
+   * @param[in] sourceDataIDs Data indexes which are to be added
+   * @param[in] targetDataID Data in which the action will be applied
+   *
+   */
   SummationAction(
       Timing                  timing,
       const std::vector<int> &sourceDataIDs,
       int                     targetDataID,
-      const mesh::PtrMesh &   mesh);
-
-  virtual ~SummationAction() {}
+      const mesh::PtrMesh    &mesh);
 
   /// Adding data and applying them to target
-  virtual void performAction(
-      double time,
-      double timeStepSize,
-      double computedTimeWindowPart,
-      double timeWindowSize);
+  void performAction() final override;
 
 private:
   logging::Logger _log{"action::SummationAction"};
@@ -42,5 +35,4 @@ private:
   std::vector<mesh::PtrData> _sourceDataVector;
 };
 
-} // namespace action
-} // namespace precice
\ No newline at end of file
+} // namespace precice::action
