@@ -4,12 +4,11 @@
 #include <string>
 #include "com/SharedPointer.hpp"
 
-namespace precice {
-namespace com {
+namespace precice::com {
 class CommunicationFactory {
 
 public:
-  virtual ~CommunicationFactory(){};
+  virtual ~CommunicationFactory() = default;
 
   virtual PtrCommunication newCommunication() = 0;
 
@@ -18,5 +17,4 @@ public:
     throw std::runtime_error("Not available!");
   }
 };
-} // namespace com
-} // namespace precice
+} // namespace precice::com
