@@ -1,9 +1,7 @@
 #include "RelativeConvergenceMeasure.hpp"
 #include "logging/LogMacros.hpp"
 
-namespace precice {
-namespace cplscheme {
-namespace impl {
+namespace precice::cplscheme::impl {
 
 RelativeConvergenceMeasure::RelativeConvergenceMeasure(double convergenceLimitPercent)
     : _convergenceLimitPercent(convergenceLimitPercent)
@@ -11,6 +9,4 @@ RelativeConvergenceMeasure::RelativeConvergenceMeasure(double convergenceLimitPe
   PRECICE_ASSERT(math::greater(_convergenceLimitPercent, 0.0) && math::greaterEquals(1.0, _convergenceLimitPercent),
                  "Relative convergence limit has to be in ]0;1] !");
 }
-} // namespace impl
-} // namespace cplscheme
-} // namespace precice
+} // namespace precice::cplscheme::impl
