@@ -2,14 +2,10 @@
 
 #include <memory>
 
-namespace precice {
-namespace cplscheme {
-namespace impl {
+namespace precice::cplscheme::impl {
 
 class ConvergenceMeasure;
 class ParallelMatrixOperations;
 
 using PtrConvergenceMeasure = std::shared_ptr<ConvergenceMeasure>;
-} // namespace impl
-} // namespace cplscheme
-} // namespace precice
+} // namespace precice::cplscheme::impl
