@@ -1,11 +1,12 @@
 #pragma once
 
 #include <string>
+#include <string_view>
+
 #include "logging/Logger.hpp"
 #include "m2n/SharedPointer.hpp"
 
-namespace precice {
-namespace m2n {
+namespace precice::m2n {
 
 /// An M2N between participants with a configured direction
 class BoundM2N {
@@ -14,7 +15,7 @@ public:
   void prepareEstablishment();
 
   /// Connect the Primary Ranks of the M2N
-  void connectPrimaryRanks();
+  void connectPrimaryRanks(std::string_view configHash);
 
   /// Connect the Secondary ranks of the M2N
   void connectSecondaryRanks();
@@ -31,16 +32,15 @@ public:
   bool        isRequesting = false;
 
 private:
-  mutable logging::Logger _log{"impl::SolverInterfaceImpl"};
+  mutable logging::Logger _log{"impl::ParticipantImpl"};
 
   /** Instructs the Primary rank wait for SecondaryRanks.
    *
    * Performs a collective operation which forces every secondary rank to sync with the Primary.
-   * 
+   *
    * @note this does nothing if the participant is running serially.
    */
   void waitForSecondaryRanks();
 };
 
-} // namespace m2n
-} // namespace precice
+} // namespace precice::m2n
