@@ -6,8 +6,7 @@
 
 #include "com/SharedPointer.hpp"
 
-namespace precice {
-namespace m2n {
+namespace precice::m2n {
 
 PointToPointComFactory::PointToPointComFactory(com::PtrCommunicationFactory comFactory)
     : _comFactory(std::move(comFactory)) {}
@@ -18,5 +17,4 @@ PointToPointComFactory::newDistributedCommunication(mesh::PtrMesh mesh)
   return DistributedCommunication::SharedPointer(new PointToPointCommunication(_comFactory, mesh));
 }
 
-} // namespace m2n
-} // namespace precice
+} // namespace precice::m2n
