@@ -12,27 +12,26 @@
 #include <vector>
 
 #include "PointToPointCommunication.hpp"
-#include "com/CommunicateMesh.hpp"
 #include "com/Communication.hpp"
 #include "com/CommunicationFactory.hpp"
+#include "com/Extra.hpp"
 #include "com/Request.hpp"
 #include "logging/LogMacros.hpp"
 #include "m2n/DistributedCommunication.hpp"
 #include "mesh/Mesh.hpp"
-#include "precice/types.hpp"
-#include "utils/Event.hpp"
+#include "precice/impl/Types.hpp"
+#include "profiling/Event.hpp"
 #include "utils/IntraComm.hpp"
+#include "utils/algorithm.hpp"
 #include "utils/assertion.hpp"
 
-using precice::utils::Event;
+using precice::profiling::Event;
 
-namespace precice {
-bool extern syncMode;
-namespace m2n {
+namespace precice::m2n {
 
 void send(mesh::Mesh::VertexDistribution const &m,
           int                                   rankReceiver,
-          const com::PtrCommunication &         communication)
+          const com::PtrCommunication          &communication)
 {
   communication->send(static_cast<int>(m.size()), rankReceiver);
 
@@ -46,9 +45,8 @@ void send(mesh::Mesh::VertexDistribution const &m,
 
 void receive(mesh::Mesh::VertexDistribution &m,
              int                             rankSender,
-             const com::PtrCommunication &   communication)
+             const com::PtrCommunication    &communication)
 {
-  using precice::com::AsVectorTag;
   m.clear();
   int size = 0;
   communication->receive(size, rankSender);
@@ -56,12 +54,12 @@ void receive(mesh::Mesh::VertexDistribution &m,
   while (size--) {
     Rank rank = -1;
     communication->receive(rank, rankSender);
-    m[rank] = communication->receiveRange(rankSender, AsVectorTag<int>{});
+    m[rank] = communication->receiveRange(rankSender, com::asVector<int>);
   }
 }
 
 void broadcastSend(mesh::Mesh::VertexDistribution const &m,
-                   const com::PtrCommunication &         communication = utils::IntraComm::getCommunication())
+                   const com::PtrCommunication          &communication = utils::IntraComm::getCommunication())
 {
   communication->broadcast(static_cast<int>(m.size()));
 
@@ -75,7 +73,7 @@ void broadcastSend(mesh::Mesh::VertexDistribution const &m,
 
 void broadcastReceive(mesh::Mesh::VertexDistribution &m,
                       int                             rankBroadcaster,
-                      const com::PtrCommunication &   communication = utils::IntraComm::getCommunication())
+                      const com::PtrCommunication    &communication = utils::IntraComm::getCommunication())
 {
   m.clear();
   int size = 0;
@@ -247,12 +245,18 @@ void printLocalIndexCountStats(std::map<int, std::vector<int>> const &m)
  *
  * @returns the resulting communication map for rank thisRank
  *
- * The approximate complexity of this function is:
- * \f$ \mathcal{O}(n \log(n) + m \log(n)) \f$
+ * The worst case complexity of the function is:
+ * \f$ \mathcal{O}(p 2 (2 n)) \f$
  *
- * * n is the total number of data indices for all ranks in `otherVertexDistribution'
- * * m is the number of local data indices for the current rank in `thisVertexDistribution`
+ * which consists of the computation of all intersections.
  *
+ * * n is the number of data indices for each vector in `otherVertexDistribution'
+ * * p number of ranks
+ * * Note that n becomes smaller, if we have more ranks.
+ *
+ * However, in case of a proper partitioning and communication between neighbor
+ * ranks (r), we would most likely end up with a factor r<<p
+ * \f$ \mathcal{O}(r 2 (2 n)) \f$
  */
 std::map<int, std::vector<int>> buildCommunicationMap(
     // `thisVertexDistribution' is input vertex distribution from this participant.
@@ -262,27 +266,40 @@ std::map<int, std::vector<int>> buildCommunicationMap(
     int                                   thisRank = utils::IntraComm::getRank())
 {
   auto iterator = thisVertexDistribution.find(thisRank);
-  if (iterator == thisVertexDistribution.end())
+  if (iterator == thisVertexDistribution.end()) {
     return {};
-
-  // Build lookup table from otherIndex -> rank for the otherVertexDistribution
-  const auto lookupIndexRank = [&otherVertexDistribution] {
-    boost::container::flat_multimap<int, int> lookupIndexRank;
-    for (const auto &other : otherVertexDistribution) {
-      for (const auto &otherIndex : other.second) {
-        lookupIndexRank.emplace(otherIndex, other.first);
-      }
-    }
-    return lookupIndexRank;
-  }();
-
-  auto const &indices = iterator->second;
+  }
 
   std::map<int, std::vector<int>> communicationMap;
-  for (size_t index = 0lu; index < indices.size(); ++index) {
-    auto range = lookupIndexRank.equal_range(indices[index]);
-    for (auto iter = range.first; iter != range.second; ++iter) {
-      communicationMap[iter->second].push_back(index);
+  // first a safety check, that we are actually sorted, as the function below operates
+  // on sorted data sets
+  PRECICE_ASSERT(std::is_sorted(iterator->second.begin(), iterator->second.end()));
+
+  // now we iterate over all other vertex distributions to compute the intersection
+  for (const auto &[rank, vertices] : otherVertexDistribution) {
+    // first a safety check, that we are actually sorted, as the function below operates
+    // on sorted data sets
+    PRECICE_ASSERT(std::is_sorted(vertices.begin(), vertices.end()));
+
+    // before starting to compute an actual intersection, we first check if elements can
+    // possibly be in both data sets by comparing upper and lower index bounds of both
+    // data sets. For typical partitioning schemes, each rank only exchanges data with
+    // a few neighbors such that this check already filters out a significant amount of
+    // computations
+    if (iterator->second.empty() || vertices.empty() || (vertices.back() < iterator->second.at(0)) || (vertices.at(0) > iterator->second.back())) {
+      // in this case there is nothing to be done
+      continue;
+    }
+    // we have an intersection, let's compute it
+    std::vector<int> inters;
+    // the actual worker function, which gives us the indices of intersecting elements
+    // have a look at the documentation of the function for more details
+    precice::utils::set_intersection_indices(iterator->second.begin(), iterator->second.begin(), iterator->second.end(),
+                                             vertices.begin(), vertices.end(),
+                                             std::back_inserter(inters));
+    // we have the results, now commit it into the final map
+    if (!inters.empty()) {
+      communicationMap.insert({rank, std::move(inters)});
     }
   }
   return communicationMap;
@@ -313,8 +330,8 @@ void PointToPointCommunication::acceptConnection(std::string const &acceptorName
   PRECICE_TRACE(acceptorName, requesterName);
   PRECICE_ASSERT(not isConnected(), "Already connected.");
 
-  mesh::Mesh::VertexDistribution &vertexDistribution = _mesh->getVertexDistribution();
-  mesh::Mesh::VertexDistribution  requesterVertexDistribution;
+  mesh::Mesh::VertexDistribution vertexDistribution = _mesh->getVertexDistribution();
+  mesh::Mesh::VertexDistribution requesterVertexDistribution;
 
   if (not utils::IntraComm::isSecondary()) {
     PRECICE_DEBUG("Exchange vertex distribution between both primary ranks");
@@ -330,8 +347,11 @@ void PointToPointCommunication::acceptConnection(std::string const &acceptorName
   }
 
   PRECICE_DEBUG("Broadcast vertex distributions");
-  Event e1("m2n.broadcastVertexDistributions", precice::syncMode);
+  Event e1("m2n.broadcastVertexDistributions", profiling::Synchronize);
   m2n::broadcast(vertexDistribution);
+  if (utils::IntraComm::isSecondary()) {
+    _mesh->setVertexDistribution(vertexDistribution);
+  }
   m2n::broadcast(requesterVertexDistribution);
   e1.stop();
 
@@ -352,7 +372,7 @@ void PointToPointCommunication::acceptConnection(std::string const &acceptorName
   //   the remote process with rank 1;
   // - has to communicate (send/receive) data with local indices 0 and 2 with
   //   the remote process with rank 4.
-  Event                           e2("m2n.buildCommunicationMap", precice::syncMode);
+  Event                           e2("m2n.buildCommunicationMap", profiling::Synchronize);
   std::map<int, std::vector<int>> communicationMap = m2n::buildCommunicationMap(
       vertexDistribution, requesterVertexDistribution);
   e2.stop();
@@ -437,8 +457,8 @@ void PointToPointCommunication::requestConnection(std::string const &acceptorNam
   PRECICE_TRACE(acceptorName, requesterName);
   PRECICE_ASSERT(not isConnected(), "Already connected.");
 
-  mesh::Mesh::VertexDistribution &vertexDistribution = _mesh->getVertexDistribution();
-  mesh::Mesh::VertexDistribution  acceptorVertexDistribution;
+  mesh::Mesh::VertexDistribution vertexDistribution = _mesh->getVertexDistribution();
+  mesh::Mesh::VertexDistribution acceptorVertexDistribution;
 
   if (not utils::IntraComm::isSecondary()) {
     PRECICE_DEBUG("Exchange vertex distribution between both primary ranks");
@@ -455,8 +475,11 @@ void PointToPointCommunication::requestConnection(std::string const &acceptorNam
   }
 
   PRECICE_DEBUG("Broadcast vertex distributions");
-  Event e1("m2n.broadcastVertexDistributions", precice::syncMode);
+  Event e1("m2n.broadcastVertexDistributions", profiling::Synchronize);
   m2n::broadcast(vertexDistribution);
+  if (utils::IntraComm::isSecondary()) {
+    _mesh->setVertexDistribution(vertexDistribution);
+  }
   m2n::broadcast(acceptorVertexDistribution);
   e1.stop();
 
@@ -477,7 +500,7 @@ void PointToPointCommunication::requestConnection(std::string const &acceptorNam
   //   the remote process with rank 1;
   // - has to communicate (send/receive) data with local indices 0 and 2 with
   //   the remote process with rank 4.
-  Event                           e2("m2n.buildCommunicationMap", precice::syncMode);
+  Event                           e2("m2n.buildCommunicationMap", profiling::Synchronize);
   std::map<int, std::vector<int>> communicationMap = m2n::buildCommunicationMap(
       vertexDistribution, acceptorVertexDistribution);
   e2.stop();
@@ -631,7 +654,7 @@ void PointToPointCommunication::receive(precice::span<double> itemsToReceive, in
   }
 }
 
-void PointToPointCommunication::broadcastSend(const int &itemToSend)
+void PointToPointCommunication::broadcastSend(int itemToSend)
 {
   for (auto &connectionData : _connectionDataVector) {
     _communication->send(itemToSend, connectionData.remoteRank);
@@ -651,14 +674,14 @@ void PointToPointCommunication::broadcastReceiveAll(std::vector<int> &itemToRece
 void PointToPointCommunication::broadcastSendMesh()
 {
   for (auto &connectionData : _connectionDataVector) {
-    com::CommunicateMesh(_communication).sendMesh(*_mesh, connectionData.remoteRank);
+    com::sendMesh(*_communication, connectionData.remoteRank, *_mesh);
   }
 }
 
 void PointToPointCommunication::broadcastReceiveAllMesh()
 {
   for (auto &connectionData : _connectionDataVector) {
-    com::CommunicateMesh(_communication).receiveMesh(*_mesh, connectionData.remoteRank);
+    com::receiveMesh(*_communication, connectionData.remoteRank, *_mesh);
   }
 }
 
@@ -671,9 +694,8 @@ void PointToPointCommunication::scatterAllCommunicationMap(CommunicationMap &loc
 
 void PointToPointCommunication::gatherAllCommunicationMap(CommunicationMap &localCommunicationMap)
 {
-  using precice::com::AsVectorTag;
   for (auto &connectionData : _connectionDataVector) {
-    localCommunicationMap[connectionData.remoteRank] = _communication->receiveRange(connectionData.remoteRank, AsVectorTag<int>{});
+    localCommunicationMap[connectionData.remoteRank] = _communication->receiveRange(connectionData.remoteRank, com::asVector<int>);
   }
 }
 
@@ -694,5 +716,4 @@ void PointToPointCommunication::checkBufferedRequests(bool blocking)
   } while (blocking);
 }
 
-} // namespace m2n
-} // namespace precice
+} // namespace precice::m2n
