@@ -1,6 +1,7 @@
 #pragma once
 
 #include <iosfwd>
+#include <precice/export.h>
 #include <string>
 
 namespace precice {
@@ -8,7 +9,7 @@ namespace precice {
 /** @brief Contains the preCICE tooling API
  *
  * The contained methods allow to query internal information of preCICE
- * without having to create a \ref precice::SolverInterface.
+ * without having to create a \ref precice::Participant.
  *
  * @note These functions are not exposed via the bindings
  *
@@ -35,11 +36,22 @@ enum struct ConfigReferenceType {
  *
  * @see \ref precice::tooling::ConfigReferenceType
  */
-void printConfigReference(std::ostream &out, ConfigReferenceType reftype);
+PRECICE_API void printConfigReference(std::ostream &out, ConfigReferenceType reftype);
 
 /// @brief Checks a given configuration
-void checkConfiguration(const std::string &filename, const std::string &participant, int size);
+PRECICE_API void checkConfiguration(const std::string &filename, const std::string &participant, int size);
 
 } // namespace tooling
 
+/**
+ * @brief Returns information on the version of preCICE.
+ *
+ * Returns a semicolon-separated C-string containing:
+ *
+ * 1) the version of preCICE
+ * 2) the revision information of preCICE
+ * 3) the configuration of preCICE including MPI, PETSC, PYTHON
+ */
+PRECICE_API std::string getVersionInformation();
+
 } // namespace precice
