@@ -2,8 +2,7 @@
 
 #include <iosfwd>
 
-namespace precice {
-namespace xml {
+namespace precice::xml {
 
 class XMLTag;
 
@@ -16,5 +15,4 @@ void toDTD(std::ostream &out, const XMLTag &tag);
 /// Prints the XML reference for the given tag.
 void toDocumentation(std::ostream &out, const XMLTag &tag);
 
-} // namespace xml
-} // namespace precice
+} // namespace precice::xml
